@@ -1,4 +1,4 @@
-__version__ = '1.1.0'
+__version__ = '1.2.0'
 
 from loupe.core import array
 
@@ -37,7 +37,8 @@ from loupe.util import (
     randn,
     centroid,
     shift,
-    register
+    register,
+    medfix2
 )
 
 from loupe.zernike import (
